package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcArchive;

/**
 * cmc成果归档Mapper接口
 * 
 * @author cmc
 * @date 2024-04-29
 */
public interface CmcArchiveMapper 
{
    /**
     * 查询cmc成果归档
     * 
     * @param archiveId cmc成果归档主键
     * @return cmc成果归档
     */
    public CmcArchive selectCmcArchiveByArchiveId(String archiveId);

    /**
     * 查询cmc成果归档列表
     * 
     * @param cmcArchive cmc成果归档
     * @return cmc成果归档集合
     */
    public List<CmcArchive> selectCmcArchiveList(CmcArchive cmcArchive);

    /**
     * 新增cmc成果归档
     * 
     * @param cmcArchive cmc成果归档
     * @return 结果
     */
    public int insertCmcArchive(CmcArchive cmcArchive);

    /**
     * 修改cmc成果归档
     * 
     * @param cmcArchive cmc成果归档
     * @return 结果
     */
    public int updateCmcArchive(CmcArchive cmcArchive);

    /**
     * 删除cmc成果归档
     * 
     * @param archiveId cmc成果归档主键
     * @return 结果
     */
    public int deleteCmcArchiveByArchiveId(String archiveId);

    /**
     * 批量删除cmc成果归档
     * 
     * @param archiveIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcArchiveByArchiveIds(String[] archiveIds);
}
